@@ -27,12 +27,12 @@ class HoldingsHelper:
 
         Args:
             holdings_record (dict): The Holdingsrecord
-            fields_criteria (list[str]): names of the properties of the holdingsrecord.
+            fields_criterias (list[str]): names of the properties of the holdingsrecord.
             migration_report (MigrationReport): Report to help reporting merge
             holdings_type_id_to_exclude_from_merging: (str): the holdings type UUID to exclude
 
         Raises:
-            exception: _description_
+            Exception: _description_
 
         Returns:
             str: _description_
@@ -108,16 +108,31 @@ class HoldingsHelper:
 
     @staticmethod
     def merge_holding(holdings_record: dict, incoming_holdings: dict) -> dict:
-        extend_list("holdingsStatementsForIndexes", holdings_record, incoming_holdings)
-        extend_list("holdingsStatements", holdings_record, incoming_holdings)
-        extend_list("holdingsStatementsForSupplements", holdings_record, incoming_holdings)
+        extend_list("holdingsStatementsForIndexes", holdings_record, incoming_holdings, True)
+        extend_list("holdingsStatements", holdings_record, incoming_holdings, True)
+        extend_list("holdingsStatementsForSupplements", holdings_record, incoming_holdings, True)
         extend_list("notes", holdings_record, incoming_holdings)
         holdings_record["notes"] = dedupe(holdings_record.get("notes", []))
         extend_list("formerIds", holdings_record, incoming_holdings)
-        holdings_record["formerIds"] = list(set(holdings_record["formerIds"]))
         extend_list("electronicAccess", holdings_record, incoming_holdings)
+        HoldingsHelper.remove_empty_holdings_statements(holdings_record)
         return holdings_record
 
+    @staticmethod
+    def remove_empty_holdings_statements(holdings_record: dict):
+        keys = [
+            "holdingsStatements",
+            "holdingsStatementsForIndexes",
+            "holdingsStatementsForSupplements",
+        ]
+
+        for key in keys:
+            if key in holdings_record:
+                temp_l = [stmt for stmt in holdings_record[key] if any(stmt.values())]
+                holdings_record[key] = temp_l
+            if key in holdings_record and not holdings_record.get(key, []):
+                del holdings_record[key]
+
     @staticmethod
     def handle_notes(folio_object):
         if folio_object.get("notes", []):
@@ -137,13 +152,17 @@ class HoldingsHelper:
                 del folio_object["notes"]
 
 
-def extend_list(prop_name: str, holdings_record: dict, incoming_holdings: dict):
+def extend_list(
+    prop_name: str, holdings_record: dict, incoming_holdings: dict, accept_dupe_items: bool = False
+):
 
     temp = holdings_record.get(prop_name, [])
+    all_already_in = all(i in temp for i in incoming_holdings.get(prop_name, []))
     for f in incoming_holdings.get(prop_name, []):
-        if f not in temp:
+        if not all_already_in and (accept_dupe_items or f not in temp):
             temp.append(f)
-    holdings_record[prop_name] = temp
+    if temp:
+        holdings_record[prop_name] = temp
 
 
 def dedupe(list_of_dicts):
