@@ -1,18 +1,19 @@
+import json
 import logging
 import sys
-import json
-import requests
+from datetime import datetime
+from datetime import timezone
 
-from folio_migration_tools.custom_exceptions import (
-    TransformationProcessError,
-    TransformationRecordFailedError,
-)
-from folioclient import FolioClient
+import requests
 from folio_uuid.folio_namespaces import FOLIONamespaces
+from folioclient import FolioClient
+
+from folio_migration_tools.custom_exceptions import TransformationProcessError
+from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
+from folio_migration_tools.library_configuration import LibraryConfiguration
 from folio_migration_tools.mapping_file_transformation.ref_data_mapping import (
     RefDataMapping,
 )
-from folio_migration_tools.library_configuration import LibraryConfiguration
 from folio_migration_tools.migration_report import MigrationReport
 from folio_migration_tools.report_blurbs import Blurbs
 
@@ -24,6 +25,7 @@ class MapperBase:
         folio_client: FolioClient,
     ):
         logging.info("MapperBase initiating")
+        self.start_datetime = datetime.now(timezone.utc)
         self.folio_client = folio_client
         self.hrid_path = "/hrid-settings-storage/hrid-settings"
         self.library_configuration: LibraryConfiguration = library_configuration
@@ -125,8 +127,17 @@ class MapperBase:
                     "a recognized field in the legacy data."
                 ),
             ) from exception
+        except KeyError as exception:
+            raise TransformationProcessError(
+                index_or_id,
+                (
+                    f"{ref_data_mapping.name} mapping - folio_{ref_data_mapping.key_type} "
+                    f"({ref_data_mapping.mapped_legacy_keys})  is not "
+                    f"a recognized field in the legacy data. KeyError: {exception}"
+                ),
+            ) from exception
         except Exception as exception:
-            raise TransformationRecordFailedError(
+            raise TransformationProcessError(
                 index_or_id,
                 (
                     f"{ref_data_mapping.name} - folio_{ref_data_mapping.key_type} "
@@ -215,7 +226,7 @@ class MapperBase:
         self, records_processed: int, error: TransformationRecordFailedError
     ):
         self.migration_report.add(Blurbs.GeneralStatistics, "Records failed due to an error")
-        error.id = error.index_or_id or records_processed
+        error.index_or_id = error.index_or_id or records_processed
         error.log_it()
         self.num_criticalerrors += 1
         if (
@@ -289,7 +300,7 @@ class MapperBase:
         legacy_id, folio_object: dict, schema: dict, object_type: FOLIONamespaces
     ):
         cleaned_folio_object = MapperBase.clean_none_props(folio_object)
-        required = schema["required"]
+        required = schema.get("required", [])
         missing = []
         for required_prop in required:
             if required_prop not in cleaned_folio_object:
