@@ -1,11 +1,18 @@
 import csv
+import itertools
 import json
 import logging
 import uuid
 from abc import abstractmethod
 from pathlib import Path
+from typing import Dict
+from typing import List
 from uuid import UUID
 
+from folio_uuid.folio_uuid import FOLIONamespaces
+from folio_uuid.folio_uuid import FolioUUID
+from folioclient import FolioClient
+
 from folio_migration_tools.custom_exceptions import TransformationFieldMappingError
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
@@ -15,9 +22,6 @@ from folio_migration_tools.mapping_file_transformation.ref_data_mapping import (
     RefDataMapping,
 )
 from folio_migration_tools.report_blurbs import Blurbs
-from folio_uuid.folio_uuid import FOLIONamespaces
-from folio_uuid.folio_uuid import FolioUUID
-from folioclient import FolioClient
 
 empty_vals = ["Not mapped", None, ""]
 
@@ -41,15 +45,24 @@ class MappingFileMapperBase(MapperBase):
         self.folio_client = folio_client
         self.use_map = True  # Legacy
         self.record_map = record_map
-        self.ref_data_dicts = {}
+        self.ref_data_dicts: Dict = {}
         self.empty_vals = empty_vals
         self.folio_keys = self.get_mapped_folio_properties_from_map(self.record_map)
         self.field_map = self.setup_field_map(ignore_legacy_identifier)
         self.validate_map()
-        self.mapped_from_values = {}
-        for k in self.record_map["data"]:
-            if k["value"] not in [None, ""] and k["folio_field"] != "legacyIdentifier":
-                self.mapped_from_values[k["folio_field"]] = k["value"]
+        try:
+            self.mapped_from_values = {
+                k["folio_field"]: k["value"]
+                for k in self.record_map["data"]
+                if k["value"] not in [None, ""] and k["folio_field"] != "legacyIdentifier"
+            }
+        except KeyError as ke:
+            raise TransformationProcessError(
+                "",
+                "Property missing from one of the settings in the record mapping file",
+                f"Property name: {ke}",
+            ) from ke
+
         logging.info(
             "Mapped values:\n%s",
             json.dumps(self.mapped_from_values, indent=4, sort_keys=True),
@@ -94,6 +107,15 @@ class MappingFileMapperBase(MapperBase):
     def setup_field_map(self, ignore_legacy_identifier):
         field_map = {}  # Map of folio_fields and source fields as an array
         for k in self.record_map["data"]:
+            if "folio_field" not in k:
+                raise TransformationProcessError(
+                    "", "Missing folio_field key in mapping", json.dumps(k)
+                )
+            if "legacy_field" not in k:
+                raise TransformationProcessError(
+                    "", "Missing legacy_field key in mapping", json.dumps(k)
+                )
+
             if not field_map.get(k["folio_field"]):
                 field_map[k["folio_field"]] = [k["legacy_field"]]
             else:
@@ -330,9 +352,10 @@ class MappingFileMapperBase(MapperBase):
         required: list[str],
     ):
         resulting_array = []
-        keys_to_map = {k.split(".")[0] for k in self.folio_keys if k.startswith(prop_name)}
+        keys_to_map = {k.split(".")[0] for k in self.folio_keys if k.startswith(f"{prop_name}[")}
         for object_key in keys_to_map:
             temp_object = {}
+            multi_field_props: List[str] = []
             for prop in (
                 k for k, p in sub_properties.items() if not p.get("folio:isVirtual", False)
             ):
@@ -340,26 +363,72 @@ class MappingFileMapperBase(MapperBase):
                 if prop_path in self.folio_keys:
                     res = self.get_prop(legacy_object, prop_path, index_or_id)
                     self.report_legacy_mapping(self.legacy_basic_property(prop), True, True)
-                    temp_object[prop] = res
 
+                    if (
+                        isinstance(res, str)
+                        and self.library_configuration.multi_field_delimiter in res
+                    ):
+                        multi_field_props.append(prop)
+
+                    temp_object[prop] = res
             if temp_object != {} and all(
                 (v or (isinstance(v, bool)) for k, v in temp_object.items() if k in required)
             ):
-                resulting_array.append(temp_object)
+                if any(multi_field_props):
+                    resulting_array.extend(
+                        self.split_obj_by_delim(
+                            self.library_configuration.multi_field_delimiter,
+                            temp_object,
+                            multi_field_props,
+                        )
+                    )
+                else:
+                    resulting_array.append(temp_object)
         if any(resulting_array):
             folio_object[prop_name] = resulting_array
 
+    @staticmethod
+    def split_obj_by_delim(delimiter: str, folio_obj: dict, delimited_props: List[str]):
+        non_split_props = [(k, v) for k, v in folio_obj.items() if k not in delimited_props]
+        delimited_props = map(lambda x: [x, *folio_obj[x].split(delimiter)], delimited_props)
+        zipped = list(zip(*delimited_props))
+        res = []
+        for (prop_name_idx, prop_name), (value_idx, ra) in itertools.product(
+            enumerate(zipped[0]), enumerate(zipped[1:])
+        ):
+            if prop_name_idx == 0:
+                res.append({prop_name: ra[prop_name_idx]})
+            else:
+                res[value_idx][prop_name] = ra[prop_name_idx]
+        for r in res:
+            r.update(non_split_props)
+        return res
+
     def map_string_array_props(self, legacy_object, prop, folio_object, index_or_id):
         keys_to_map = [k for k in self.folio_keys if k.startswith(prop)]
         for prop_name in keys_to_map:
             if prop_name in self.folio_keys and self.has_property(legacy_object, prop_name):
                 if mapped_prop := self.get_prop(legacy_object, prop_name, index_or_id):
-                    if prop in folio_object and mapped_prop not in folio_object.get(prop, []):
-                        folio_object.get(prop, []).append(mapped_prop)
-                    else:
-                        folio_object[prop] = [mapped_prop]
+                    self.add_values_to_string_array(
+                        prop,
+                        folio_object,
+                        mapped_prop,
+                        self.library_configuration.multi_field_delimiter,
+                    )
                 self.report_legacy_mapping(self.legacy_basic_property(prop_name), True, True)
 
+    @staticmethod
+    def add_values_to_string_array(prop, folio_object, mapped_prop_value, delimiter: str):
+        if prop in folio_object and mapped_prop_value not in folio_object.get(prop, []):
+            if isinstance(mapped_prop_value, str) and delimiter in mapped_prop_value:
+                folio_object.get(prop, []).extend(mapped_prop_value.split(delimiter))
+            else:
+                folio_object.get(prop, []).append(mapped_prop_value)
+        elif isinstance(mapped_prop_value, str) and delimiter in mapped_prop_value:
+            folio_object[prop] = mapped_prop_value.split(delimiter)
+        else:
+            folio_object[prop] = [mapped_prop_value]
+
     def map_basic_props(self, legacy_object, prop, folio_object, index_or_id):
         if self.has_basic_property(legacy_object, prop):  # is there a match in the csv?
             if mapped_prop := self.get_prop(legacy_object, prop, index_or_id):
@@ -373,8 +442,7 @@ class MappingFileMapperBase(MapperBase):
             reader = csv.DictReader(source_file)
         idx = 0
         try:
-            for row in reader:
-                yield row
+            yield from reader
         except Exception as exception:
             logging.error("%s at row %s", exception, idx)
             raise exception from exception
