@@ -6,13 +6,14 @@ from datetime import datetime
 from typing import Dict
 
 from dateutil.parser import parse
+from folio_uuid.folio_namespaces import FOLIONamespaces
+from folioclient import FolioClient
+
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.mapping_file_transformation.mapping_file_mapper_base import (
     MappingFileMapperBase,
 )
-from folio_migration_tools.mapping_file_transformation.mapping_file_mapping_base_impl import (
-    MappingFileMappingBaseImpl,
-)
+from folio_migration_tools.mapping_file_transformation.notes_mapper import NotesMapper
 from folio_migration_tools.mapping_file_transformation.ref_data_mapping import (
     RefDataMapping,
 )
@@ -20,8 +21,6 @@ from folio_migration_tools.mapping_file_transformation.user_mapper_base import (
     UserMapperBase,
 )
 from folio_migration_tools.report_blurbs import Blurbs
-from folio_uuid.folio_namespaces import FOLIONamespaces
-from folioclient import FolioClient
 
 
 class UserMapper(UserMapperBase):
@@ -30,24 +29,31 @@ class UserMapper(UserMapperBase):
         folio_client: FolioClient,
         task_config,
         library_config,
+        user_map,
         departments_mapping,
         groups_map,
     ):
         try:
             super().__init__(folio_client, library_config)
 
-            self.noteprops = None
             self.notes_schemas = None
-            self.notes_mapper = None
             self.task_config = task_config
             self.folio_keys = []
+            self.user_map = user_map
+            self.folio_keys = MappingFileMapperBase.get_mapped_folio_properties_from_map(user_map)
+            self.mapped_legacy_keys = MappingFileMapperBase.get_mapped_legacy_properties_from_map(
+                user_map
+            )
             self.mapped_legacy_keys = []
             self.library_config = library_config
             self.user_schema = FolioClient.get_latest_from_github(
                 "folio-org", "mod-user-import", "/ramls/schemas/userdataimport.json"
             )
+            self.notes_mapper: NotesMapper = NotesMapper(
+                self.library_config, self.folio_client, self.user_map, FOLIONamespaces.users, True
+            )
             self.ids_dict: Dict[str, set] = {}
-            self.custom_props = {}
+            self.custom_props: Dict = {}
             # TODO: Use RefDataMapping
             if departments_mapping:
                 self.departments_mapping = RefDataMapping(
@@ -71,84 +77,23 @@ class UserMapper(UserMapperBase):
                 )
             else:
                 self.groups_mapping = None
-            self.setup_notes_mapping()
             logging.info("Init done.")
         except TransformationProcessError as tpe:
             logging.critical(tpe)
-            print(f"\n{tpe.message}")
+            print(f"\n{tpe.message}\t{tpe.data_value}")
             sys.exit(1)
 
-    def setup_notes_mapping(self):
-        self.notes_schemas = FolioClient.get_latest_from_github(
-            "folio-org",
-            "mod-notes",
-            "src/main/resources/swagger.api/schemas/note.yaml",
-        )
-        notes_common = FolioClient.get_latest_from_github(
-            "folio-org",
-            "mod-notes",
-            "src/main/resources/swagger.api/schemas/common.yaml",
-        )
-        for prop in self.notes_schemas["note"]["properties"].items():
-            if prop[1].get("$ref", "") == "common.yaml#/uuid":
-                prop[1]["type"] = notes_common["uuid"]["type"]
-
-        for p in ["links", "metadata", "id"]:
-            del self.notes_schemas["note"]["properties"][p]
-
-    def map_notes(self, user_map, legacy_user, legacy_id, user_uuid: str):
-        self.setup_note_props(user_map)
-        if any(self.noteprops["data"]):
-            notes_schema = self.notes_schemas["noteCollection"]
-            notes_schema["properties"]["notes"]["items"] = self.notes_schemas["note"]
-            notes_schema["required"] = []
-            if self.notes_mapper is None:
-                self.notes_mapper = MappingFileMappingBaseImpl(
-                    self.library_config,
-                    self.folio_client,
-                    notes_schema,
-                    self.noteprops,
-                    FOLIONamespaces.other,
-                    True,
-                )
-                logging.info("Initiated mapper for User notes")
-            for note in self.notes_mapper.do_map(legacy_user, legacy_id, FOLIONamespaces.other)[
-                0
-            ].get("notes", []):
-                if note.get("content", "").strip():
-                    note["links"] = [{"id": user_uuid, "type": "user"}]
-
-                    logging.log(25, "notes\t%s", json.dumps(note))
-                    self.migration_report.add(Blurbs.MappedNoteTypes, note["typeId"])
-                else:
-                    self.migration_report.add_general_statistics(
-                        "Notes without content that were discarded. Set some default "
-                        "value if you only intend to set the note title"
-                    )
-
-    def setup_note_props(self, user_map):
-        if self.noteprops is None:
-            self.noteprops = {
-                "data": [p for p in user_map["data"] if p["folio_field"].startswith("notes[")]
-            }
-            logging.info("Set %s props used for note mapping", len(self.noteprops["data"]))
-
-    def do_map(self, legacy_user, user_map, legacy_id):
-        if not self.folio_keys and not self.mapped_legacy_keys:
-            self.folio_keys = MappingFileMapperBase.get_mapped_folio_properties_from_map(user_map)
-            self.mapped_legacy_keys = MappingFileMapperBase.get_mapped_legacy_properties_from_map(
-                user_map
+    def do_map(self, legacy_user, legacy_id):
+        missing_keys_in_user = [f for f in self.mapped_legacy_keys if f not in legacy_user]
+        if any(missing_keys_in_user):
+            raise TransformationProcessError(
+                "",
+                ("There are mapped legacy fields that are not in the legacy user record"),
+                missing_keys_in_user,
             )
-            missing_keys_in_user = [f for f in self.mapped_legacy_keys if f not in legacy_user]
-            if any(missing_keys_in_user):
-                raise TransformationProcessError(
-                    "",
-                    ("There are mapped legacy fields that are not in the legacy " "user record"),
-                    missing_keys_in_user,
-                )
 
         if not self.custom_props:
-            for m in user_map["data"]:
+            for m in self.user_map["data"]:
                 if "customFields" in m["folio_field"]:
                     sub_property = m["folio_field"].split(".")[-1]
                     self.custom_props[sub_property] = m["legacy_field"]
@@ -157,7 +102,7 @@ class UserMapper(UserMapperBase):
 
         folio_user = self.instantiate_user(legacy_id)
         for prop_name, prop in self.user_schema["properties"].items():
-            self.add_prop(legacy_user, user_map, folio_user, prop_name, prop)
+            self.add_prop(legacy_user, self.user_map, folio_user, prop_name, prop)
 
         folio_user["personal"]["preferredContactTypeId"] = "Email"
         folio_user["active"] = True
@@ -167,7 +112,9 @@ class UserMapper(UserMapperBase):
             "delivery": False,
             "metadata": self.folio_client.get_metadata_construct(),
         }
-        self.map_notes(user_map, legacy_user, legacy_id, folio_user["id"])
+        self.notes_mapper.map_notes(
+            legacy_user, legacy_id, folio_user["id"], FOLIONamespaces.users
+        )
         clean_folio_object = self.validate_required_properties(
             legacy_id, folio_user, self.user_schema, FOLIONamespaces.users
         )
@@ -350,7 +297,7 @@ class UserMapper(UserMapperBase):
                 self.migration_report.add(
                     Blurbs.Details, f"{legacy_user_keys} concatenated into one string"
                 )
-            return " ".join(legacy_user.get(key, "") for key in legacy_user_keys)
+            return " ".join(legacy_user.get(key, "").strip() for key in legacy_user_keys)
         else:
             return ""
 
