@@ -3,20 +3,17 @@ import logging
 import sys
 import time
 import traceback
-from datetime import datetime as dt
 
 from folio_uuid.folio_namespaces import FOLIONamespaces
 from pymarc import Field
 from pymarc import Record
 
-from folio_migration_tools import library_configuration
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
 from folio_migration_tools.folder_structure import FolderStructure
 from folio_migration_tools.helper import Helper
 from folio_migration_tools.holdings_helper import HoldingsHelper
 from folio_migration_tools.library_configuration import FileDefinition
-from folio_migration_tools.library_configuration import FolioRelease
 from folio_migration_tools.library_configuration import HridHandling
 from folio_migration_tools.marc_rules_transformation.rules_mapper_holdings import (
     RulesMapperHoldings,
@@ -39,22 +36,15 @@ class HoldingsProcessor:
         self.setup_holdings_sources()
 
     def setup_holdings_sources(self):
-        if library_configuration.FolioRelease != FolioRelease.juniper:
-            holdings_sources = list(
-                self.mapper.folio_client.folio_get_all(
-                    "/holdings-sources", "holdingsRecordsSources"
-                )
-            )
-            logging.info("Fetched %s holdingsRecordsSources from tenant", len(holdings_sources))
-            self.holdingssources = {n["name"].upper(): n["id"] for n in holdings_sources}
-            if "FOLIO" not in self.holdingssources:
-                raise TransformationProcessError(
-                    "", "No holdings source with name FOLIO in tenant"
-                )
-            if "MARC" not in self.holdingssources:
-                raise TransformationProcessError("", "No holdings source with name MARC in tenant")
-        else:
-            self.holdingssources = {}
+        holdings_sources = list(
+            self.mapper.folio_client.folio_get_all("/holdings-sources", "holdingsRecordsSources")
+        )
+        logging.info("Fetched %s holdingsRecordsSources from tenant", len(holdings_sources))
+        self.holdingssources = {n["name"].upper(): n["id"] for n in holdings_sources}
+        if "FOLIO" not in self.holdingssources:
+            raise TransformationProcessError("", "No holdings source with name FOLIO in tenant")
+        if "MARC" not in self.holdingssources:
+            raise TransformationProcessError("", "No holdings source with name MARC in tenant")
 
     def exit_on_too_many_exceptions(self):
         if (
@@ -67,7 +57,16 @@ class HoldingsProcessor:
             sys.exit(1)
 
     def process_record(self, marc_record: Record, file_def: FileDefinition):
-        """processes a marc holdings record and saves it"""
+        """processes a marc holdings record and saves it
+
+        Args:
+            marc_record (Record): _description_
+            file_def (FileDefinition): _description_
+
+        Raises:
+            TransformationProcessError: _description_
+            Exception: _description_
+        """
         success = True
         folio_rec = {}
         try:
@@ -229,11 +228,10 @@ class HoldingsProcessor:
 
     @staticmethod
     def set_source_id(task_configuration, folio_rec, holdingssources):
-        if library_configuration.FolioRelease != FolioRelease.juniper:
-            if task_configuration.create_source_records:
-                folio_rec["sourceId"] = holdingssources.get("MARC")
-            else:
-                folio_rec["sourceId"] = holdingssources.get("FOLIO")
+        if task_configuration.create_source_records:
+            folio_rec["sourceId"] = holdingssources.get("MARC")
+        else:
+            folio_rec["sourceId"] = holdingssources.get("FOLIO")
 
     def wrap_up(self):
         """Finalizes the mapping by writing things out."""
@@ -249,8 +247,9 @@ class HoldingsProcessor:
         logging.info("%s records processed", self.records_count)
         with open(self.folder_structure.migration_reports_file, "w+") as report_file:
             report_file.write("# MFHD records transformation results   \n")
-            report_file.write(f"Time Finished: {dt.isoformat(dt.utcnow())}   \n")
-            self.mapper.migration_report.write_migration_report(report_file)
+            self.mapper.migration_report.write_migration_report(
+                report_file, self.mapper.start_datetime
+            )
             Helper.print_mapping_report(
                 report_file,
                 self.mapper.parsed_records,
