@@ -6,6 +6,13 @@ import uuid
 from textwrap import wrap
 
 import pymarc
+from folio_uuid.folio_uuid import FOLIONamespaces
+from folio_uuid.folio_uuid import FolioUUID
+from folioclient import FolioClient
+from pymarc import Field
+from pymarc import Leader
+from pymarc import Record
+
 from folio_migration_tools.custom_exceptions import TransformationFieldMappingError
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
@@ -13,12 +20,6 @@ from folio_migration_tools.helper import Helper
 from folio_migration_tools.library_configuration import LibraryConfiguration
 from folio_migration_tools.mapper_base import MapperBase
 from folio_migration_tools.report_blurbs import Blurbs
-from folio_uuid.folio_uuid import FOLIONamespaces
-from folio_uuid.folio_uuid import FolioUUID
-from folioclient import FolioClient
-from pymarc import Field
-from pymarc import Leader
-from pymarc import Record
 
 
 class RulesMapperBase(MapperBase):
@@ -58,10 +59,12 @@ class RulesMapperBase(MapperBase):
             self.last_batch_time = time.time()
 
     @staticmethod
-    def dedupe_rec(rec):
+    def dedupe_rec(rec, props_to_not_dedupe=None):
+        if props_to_not_dedupe is None:
+            props_to_not_dedupe = []
         # remove duplicates
         for key, value in rec.items():
-            if isinstance(value, list):
+            if key not in props_to_not_dedupe and isinstance(value, list):
                 res = []
                 for v in value:
                     if v not in res:
@@ -435,7 +438,16 @@ class RulesMapperBase(MapperBase):
 
     @staticmethod
     def grouped(marc_field: Field):
-        "s -> (s0,s1,s2,...sn-1), (sn,sn+1,sn+2,...s2n-1), (s2n,s2n+1,s2n+2,...s3n-1), ..."
+        """Groups the subfields
+        s -> (s0,s1,s2,...sn-1), (sn,sn+1,sn+2,...s2n-1), (s2n,s2n+1,s2n+2,...s3n-1), ...
+
+
+        Args:
+            marc_field (Field): _description_
+
+        Returns:
+            _type_: _description_
+        """
         unique_subfields = []
         repeated_subfields = []
         results = list()
@@ -466,7 +478,15 @@ class RulesMapperBase(MapperBase):
 
     @staticmethod
     def remove_repeated_subfields(marc_field: Field):
-        "s -> (s0,s1,s2,...sn-1), (sn,sn+1,sn+2,...s2n-1), (s2n,s2n+1,s2n+2,...s3n-1), ..."
+        """Removes repeated subfields
+        s -> (s0,s1,s2,...sn-1), (sn,sn+1,sn+2,...s2n-1), (s2n,s2n+1,s2n+2,...s3n-1), ...
+
+        Args:
+            marc_field (Field): _description_
+
+        Returns:
+            _type_: _description_
+        """
         new_subfields = []
         for sf, sf_vals in marc_field.subfields_as_dict().items():
             new_subfields.extend([sf, sf_vals[0]])
@@ -486,7 +506,17 @@ class RulesMapperBase(MapperBase):
         legacy_id: str,
         suppress: bool,
     ):
-        """Saves the source Marc_record to the Source record Storage module"""
+        """Saves the source Marc_record to the Source record Storage module
+
+        Args:
+            srs_records_file (_type_): _description_
+            record_type (FOLIONamespaces): _description_
+            folio_client (FolioClient): _description_
+            marc_record (Record): _description_
+            folio_record (_type_): _description_
+            legacy_id (str): _description_
+            suppress (bool): _description_
+        """
         srs_id = RulesMapperBase.create_srs_id(record_type, folio_client.okapi_url, legacy_id)
 
         marc_record.add_ordered_field(
@@ -539,7 +569,7 @@ class RulesMapperBase(MapperBase):
         folio_object: dict,
         srs_id,
         metadata_obj,
-        suppress,
+        discovery_suppress: bool,
         record_type: FOLIONamespaces,
     ):
         record_types = {
@@ -573,7 +603,7 @@ class RulesMapperBase(MapperBase):
             "recordType": record_types.get(record_type),
             "rawRecord": raw_record,
             "parsedRecord": parsed_record,
-            "additionalInfo": {"suppressDiscovery": suppress},
+            "additionalInfo": {"suppressDiscovery": discovery_suppress},
             "externalIdsHolder": id_holders.get(record_type),
             "metadata": metadata_obj,
             "state": "ACTUAL",
