@@ -13,10 +13,16 @@ from typing import Set
 import pymarc
 import requests
 from defusedxml.ElementTree import fromstring
+from folio_uuid.folio_namespaces import FOLIONamespaces
+from folio_uuid.folio_uuid import FolioUUID
+from folioclient import FolioClient
+from pymarc import Field
+from pymarc.record import Record
+
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
 from folio_migration_tools.helper import Helper
-from folio_migration_tools.library_configuration import FolioRelease
+from folio_migration_tools.library_configuration import FileDefinition
 from folio_migration_tools.library_configuration import HridHandling
 from folio_migration_tools.library_configuration import IlsFlavour
 from folio_migration_tools.library_configuration import LibraryConfiguration
@@ -25,11 +31,6 @@ from folio_migration_tools.marc_rules_transformation.rules_mapper_base import (
     RulesMapperBase,
 )
 from folio_migration_tools.report_blurbs import Blurbs
-from folio_uuid.folio_namespaces import FOLIONamespaces
-from folio_uuid.folio_uuid import FolioUUID
-from folioclient import FolioClient
-from pymarc import Field
-from pymarc.record import Record
 
 
 class BibsRulesMapper(RulesMapperBase):
@@ -50,7 +51,7 @@ class BibsRulesMapper(RulesMapperBase):
         self.folio = folio_client
         self.task_configuration = task_configuration
         self.record_status = {}
-        self.unique_001s = Set[str]
+        self.unique_001s: Set[str] = set()
         self.holdings_map = {}
         self.id_map = {}
         self.srs_recs = []
@@ -62,11 +63,7 @@ class BibsRulesMapper(RulesMapperBase):
         logging.info(f"HRID handling is set to: '{self.task_configuration.hrid_handling}'")
         self.hrid_handling: HridHandling = self.task_configuration.hrid_handling
         logging.info("Fetching mapping rules from the tenant")
-        rules_endpoint = (
-            "/mapping-rules"
-            if self.library_configuration.folio_release == FolioRelease.juniper
-            else "/mapping-rules/marc-bib"
-        )
+        rules_endpoint = "/mapping-rules/marc-bib"
         self.mappings = self.folio.folio_get_single_object(rules_endpoint)
         logging.info("Fetching valid language codes...")
         self.language_codes = list(self.fetch_language_codes())
@@ -95,10 +92,19 @@ class BibsRulesMapper(RulesMapperBase):
             Helper.log_data_issue(legacy_ids, "d in leader. Is this correct?", marc_record.leader)
         return folio_instance
 
-    def parse_bib(self, legacy_ids, marc_record: pymarc.Record, suppressed: bool):
+    def parse_bib(self, legacy_ids, marc_record: pymarc.Record, file_def: FileDefinition):
         """Parses a bib recod into a FOLIO Inventory instance object
         Community mapping suggestion: https://bit.ly/2S7Gyp3
-         This is the main function"""
+         This is the main function
+
+        Args:
+            legacy_ids (_type_): _description_
+            marc_record (pymarc.Record): _description_
+            file_def (FileDefinition): _description_
+
+        Returns:
+            _type_: _description_
+        """
         self.print_progress()
         ignored_subsequent_fields = set()
         bad_tags = set(self.task_configuration.tags_to_delete)  # "907"
@@ -113,7 +119,7 @@ class BibsRulesMapper(RulesMapperBase):
                     legacy_ids,
                 )
 
-        self.perform_additional_parsing(folio_instance, marc_record, legacy_ids, suppressed)
+        self.perform_additional_parsing(folio_instance, marc_record, legacy_ids, file_def)
         clean_folio_instance = self.validate_required_properties(
             "-".join(legacy_ids), folio_instance, self.schema, FOLIONamespaces.instances
         )
@@ -192,9 +198,16 @@ class BibsRulesMapper(RulesMapperBase):
         folio_instance: dict,
         marc_record: Record,
         legacy_ids: List[str],
-        suppressed: bool,
-    ):
-        """Do stuff not easily captured by the mapping rules"""
+        file_def: FileDefinition,
+    ) -> None:
+        """Do stuff not easily captured by the mapping rules
+
+        Args:
+            folio_instance (dict): _description_
+            marc_record (Record): _description_
+            legacy_ids (List[str]): _description_
+            file_def (FileDefinition): _description_
+        """
         folio_instance["source"] = "MARC"
         folio_instance["instanceFormatIds"] = list(
             set(self.get_instance_format_ids(marc_record, legacy_ids))
@@ -203,6 +216,11 @@ class BibsRulesMapper(RulesMapperBase):
         folio_instance["instanceTypeId"] = self.get_instance_type_id(marc_record, legacy_ids)
 
         folio_instance["modeOfIssuanceId"] = self.get_mode_of_issuance_id(marc_record, legacy_ids)
+        self.handle_languages(folio_instance, marc_record, legacy_ids)
+        self.handle_suppression(folio_instance, file_def)
+        self.handle_holdings(marc_record)
+
+    def handle_languages(self, folio_instance, marc_record, legacy_ids):
         if "languages" in folio_instance:
             folio_instance["languages"].extend(self.get_languages(marc_record, legacy_ids))
         else:
@@ -210,9 +228,12 @@ class BibsRulesMapper(RulesMapperBase):
         folio_instance["languages"] = list(
             self.filter_langs(folio_instance["languages"], marc_record, legacy_ids)
         )
-        folio_instance["discoverySuppress"] = suppressed
-        folio_instance["staffSuppress"] = False
-        self.handle_holdings(marc_record)
+
+    def handle_suppression(self, folio_instance, file_def):
+        folio_instance["discoverySuppress"] = file_def.suppressed
+        self.migration_report.add_general_statistics("Suppressed from discovery")
+        folio_instance["staffSuppress"] = file_def.staff_suppressed
+        self.migration_report.add_general_statistics("Staff suppressed")
 
     def handle_holdings(self, marc_record: Record):
         if "852" in marc_record:
@@ -427,7 +448,16 @@ class BibsRulesMapper(RulesMapperBase):
                                     yield get_folio_id(combined_code)
 
     def handle_hrid(self, folio_instance, marc_record: Record, legacy_ids) -> None:
-        """Create HRID if not mapped. Add hrid as MARC record 001"""
+        """Create HRID if not mapped. Add hrid as MARC record 001
+
+        Args:
+            folio_instance (_type_): _description_
+            marc_record (Record): _description_
+            legacy_ids (_type_): _description_
+
+        Raises:
+            TransformationProcessError: _description_
+        """
         if self.hrid_handling == HridHandling.default or "001" not in marc_record:
             num_part = str(self.instance_hrid_counter).zfill(11)
             folio_instance["hrid"] = f"{self.instance_hrid_prefix}{num_part}"
@@ -489,7 +519,7 @@ class BibsRulesMapper(RulesMapperBase):
         else:
             raise TransformationProcessError("", f"Unknown HRID handling: {self.hrid_handling}")
 
-    def get_mode_of_issuance_id(self, marc_record: Record, legacy_id: str) -> str:
+    def get_mode_of_issuance_id(self, marc_record: Record, legacy_id: List[str]) -> str:
         level = marc_record.leader[7]
         try:
             name = "unspecified"
@@ -560,7 +590,15 @@ class BibsRulesMapper(RulesMapperBase):
         return languages
 
     def get_languages(self, marc_record: Record, legacy_id: str) -> List[str]:
-        """Get languages and tranforms them to correct codes"""
+        """Get languages and tranforms them to correct codes
+
+        Args:
+            marc_record (Record): _description_
+            legacy_id (str): _description_
+
+        Returns:
+            List[str]: _description_
+        """
         languages = self.get_languages_041(marc_record, legacy_id)
         languages.add(self.get_languages_008(marc_record))
         for lang in languages:
@@ -568,7 +606,11 @@ class BibsRulesMapper(RulesMapperBase):
         return list(languages)
 
     def fetch_language_codes(self) -> Generator[str, None, None]:
-        """fetches the list of standardized language codes from LoC"""
+        """fetches the list of standardized language codes from LoC
+
+        Yields:
+            Generator[str, None, None]: _description_
+        """
         url = "https://www.loc.gov/standards/codelists/languages.xml"
         tree = fromstring(requests.get(url).content)
         name_space = "{info:lc/xmlns/codelist-v1}"
