@@ -1,5 +1,10 @@
 import logging
 
+from folio_uuid.folio_namespaces import FOLIONamespaces
+from folio_uuid.folio_uuid import FolioUUID
+from pymarc.field import Field
+from pymarc.record import Record
+
 from folio_migration_tools.custom_exceptions import TransformationFieldMappingError
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
@@ -14,10 +19,6 @@ from folio_migration_tools.marc_rules_transformation.rules_mapper_base import (
     RulesMapperBase,
 )
 from folio_migration_tools.report_blurbs import Blurbs
-from folio_uuid.folio_namespaces import FOLIONamespaces
-from folio_uuid.folio_uuid import FolioUUID
-from pymarc.field import Field
-from pymarc.record import Record
 
 
 class RulesMapperHoldings(RulesMapperBase):
@@ -48,7 +49,18 @@ class RulesMapperHoldings(RulesMapperBase):
     def parse_hold(self, marc_record, legacy_id):
         """Parses a mfhd recod into a FOLIO Inventory instance object
         Community mapping suggestion: https://tinyurl.com/3rh52e2x
-         This is the main function"""
+         This is the main function
+
+        Args:
+            marc_record (_type_): _description_
+            legacy_id (_type_): _description_
+
+        Raises:
+            TransformationRecordFailedError: _description_
+
+        Returns:
+            _type_: _description_
+        """
         self.print_progress()
         folio_holding = {
             "metadata": self.folio_client.get_metadata_construct(),
@@ -92,7 +104,16 @@ class RulesMapperHoldings(RulesMapperBase):
             self.holdings_json_schema,
             FOLIONamespaces.holdings,
         )
-        self.dedupe_rec(cleaned_folio_holding)
+        props_to_not_dedupe = (
+            []
+            if self.task_configuration.deduplicate_holdings_statements
+            else [
+                "holdingsStatements",
+                "holdingsStatementsForIndexes",
+                "holdingsStatementsForSupplements",
+            ]
+        )
+        self.dedupe_rec(cleaned_folio_holding, props_to_not_dedupe)
         self.holdings_id_map[legacy_id] = self.get_id_map_dict(legacy_id, cleaned_folio_holding)
 
         self.report_folio_mapping(cleaned_folio_holding, self.schema)
@@ -118,7 +139,13 @@ class RulesMapperHoldings(RulesMapperBase):
                 ignored_subsequent_fields.add(marc_field.tag)
 
     def perform_additional_mapping(self, marc_record: Record, folio_holding, legacy_id: str):
-        """Perform additional tasks not easily handled in the mapping rules"""
+        """Perform additional tasks not easily handled in the mapping rules
+
+        Args:
+            marc_record (Record): _description_
+            folio_holding (_type_): _description_
+            legacy_id (str): _description_
+        """
         self.set_holdings_type(marc_record, folio_holding, legacy_id)
         self.set_default_call_number_type_if_empty(folio_holding)
         self.pick_first_location_if_many(folio_holding, legacy_id)
@@ -145,9 +172,15 @@ class RulesMapperHoldings(RulesMapperBase):
         for key, v in a.items():
             try:
                 res = HoldingsStatementsParser.get_holdings_statements(
-                    marc_record, v[0], v[1], v[2], legacy_id
+                    marc_record,
+                    v[0],
+                    v[1],
+                    v[2],
+                    legacy_id,
+                    self.task_configuration.deduplicate_holdings_statements,
                 )
-                folio_holding[key] = res["statements"]
+                if res["statements"]:
+                    folio_holding[key] = res["statements"]
                 for mr in res["migration_report"]:
                     self.migration_report.add(
                         Blurbs.HoldingsStatementsParsing, f"{mr[0]} -- {mr[1]}"
@@ -220,7 +253,11 @@ class RulesMapperHoldings(RulesMapperBase):
             folio_holding["callNumberTypeId"] = self.conditions.default_call_number_type["id"]
 
     def remove_from_id_map(self, former_ids):
-        """removes the ID from the map in case parsing failed"""
+        """removes the ID from the map in case parsing failed
+
+        Args:
+            former_ids (_type_): _description_
+        """
         for former_id in [id for id in former_ids if id]:
             if former_id in self.holdings_id_map:
                 del self.holdings_id_map[former_id]
