@@ -8,24 +8,22 @@ import sys
 import time
 import traceback
 import uuid
-from os.path import isfile
-from typing import List, Optional
-from folioclient import FolioClient
+from typing import List
+from typing import Optional
 
 from folio_uuid import FolioUUID
 from folio_uuid.folio_namespaces import FOLIONamespaces
-from folio_migration_tools.custom_exceptions import (
-    TransformationProcessError,
-    TransformationRecordFailedError,
-)
+from folioclient import FolioClient
+from pydantic.main import BaseModel
+from requests import HTTPError
+
+from folio_migration_tools.custom_exceptions import TransformationProcessError
+from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
 from folio_migration_tools.helper import Helper
 from folio_migration_tools.holdings_helper import HoldingsHelper
-from folio_migration_tools.library_configuration import (
-    FileDefinition,
-    FolioRelease,
-    HridHandling,
-    LibraryConfiguration,
-)
+from folio_migration_tools.library_configuration import FileDefinition
+from folio_migration_tools.library_configuration import HridHandling
+from folio_migration_tools.library_configuration import LibraryConfiguration
 from folio_migration_tools.mapping_file_transformation.holdings_mapper import (
     HoldingsMapper,
 )
@@ -33,8 +31,6 @@ from folio_migration_tools.mapping_file_transformation.mapping_file_mapper_base
     MappingFileMapperBase,
 )
 from folio_migration_tools.migration_tasks.migration_task_base import MigrationTaskBase
-from pydantic.main import BaseModel
-
 
 csv.field_size_limit(int(ctypes.c_ulong(-1).value // 2))
 csv.register_dialect("tsv", delimiter="\t")
@@ -74,7 +70,6 @@ class HoldingsCsvTransformer(MigrationTaskBase):
         try:
             self.task_config = task_config
             self.bound_with_keys = set()
-            self.files = self.list_source_files()
             self.mapper = HoldingsMapper(
                 self.folio_client,
                 self.load_mapped_fields(),
@@ -93,7 +88,9 @@ class HoldingsCsvTransformer(MigrationTaskBase):
             )
             logging.info("%s\tholdings types in tenant", len(self.holdings_types))
             self.validate_merge_criterias()
-
+            self.check_source_files(
+                self.folder_structure.data_folder / "items", self.task_config.files
+            )
             self.fallback_holdings_type = next(
                 h
                 for h in self.holdings_types
@@ -126,7 +123,10 @@ class HoldingsCsvTransformer(MigrationTaskBase):
 
             else:
                 logging.info("No file of legacy holdings setup.")
-        except TransformationProcessError as process_error:
+        except HTTPError as http_error:
+            logging.critical(http_error)
+            sys.exit(1)
+        except (FileNotFoundError, TransformationProcessError) as process_error:
             logging.critical(process_error)
             logging.critical("Halting.")
             sys.exit(1)
@@ -135,6 +135,7 @@ class HoldingsCsvTransformer(MigrationTaskBase):
             logging.info(exception)
             logging.info("\n=======Stack Trace===========")
             traceback.print_exc()
+            sys.exit(1)
         logging.info("Init done")
 
     def load_call_number_type_map(self):
@@ -176,24 +177,6 @@ class HoldingsCsvTransformer(MigrationTaskBase):
             )
             return holdings_map
 
-    def list_source_files(self):
-        # Source data files
-        files = [
-            self.folder_structure.data_folder / "items" / f.file_name
-            for f in self.task_config.files
-            if isfile(self.folder_structure.data_folder / "items" / f.file_name)
-        ]
-        if not any(files):
-            ret_str = ",".join(f.file_name for f in self.task_config.files)
-            raise TransformationProcessError(
-                "",
-                f"Files {ret_str} not found in {self.folder_structure.data_folder / 'items'}",
-            )
-        logging.info("Files to process:")
-        for filename in files:
-            logging.info("\t%s", filename)
-        return files
-
     def load_instance_id_map(self):
         res = {}
         with open(self.folder_structure.instance_id_map_path, "r") as instance_id_map_file:
@@ -208,19 +191,21 @@ class HoldingsCsvTransformer(MigrationTaskBase):
 
     def do_work(self):
         logging.info("Starting....")
-        for file_name in self.files:
-            logging.info("Processing %s", file_name)
+        for file_def in self.task_config.files:
+            logging.info("Processing %s", file_def.file_name)
             try:
-                self.process_single_file(file_name)
+                self.process_single_file(file_def)
             except Exception as ee:
                 error_str = (
-                    f"Processing of {file_name} failed:\n{ee}."
+                    f"Processing of {file_def.file_name} failed:\n{ee}."
                     "\nCheck source files for empty lines or missing reference data"
                 )
                 logging.critical(error_str)
                 print(f"\n{error_str}\nHalting")
                 sys.exit(1)
-        logging.info(f"processed {self.total_records:,} records in {len(self.files)} files")
+        logging.info(
+            f"processed {self.total_records:,} records in {len(self.task_config.files)} files"
+        )
 
     def wrap_up(self):
         logging.info("Work done. Wrapping up...")
@@ -250,7 +235,9 @@ class HoldingsCsvTransformer(MigrationTaskBase):
                 "Writing migration- and mapping report to %s",
                 self.folder_structure.migration_reports_file,
             )
-            self.mapper.migration_report.write_migration_report(migration_report_file)
+            self.mapper.migration_report.write_migration_report(
+                migration_report_file, self.mapper.start_datetime
+            )
             Helper.print_mapping_report(
                 migration_report_file,
                 self.total_records,
@@ -275,12 +262,13 @@ class HoldingsCsvTransformer(MigrationTaskBase):
             )
             sys.exit(1)
 
-    def process_single_file(self, file_name):
-        with open(file_name, encoding="utf-8-sig") as records_file:
+    def process_single_file(self, file_def: FileDefinition):
+        full_path = self.folder_structure.data_folder / "items" / file_def.file_name
+        with open(full_path, encoding="utf-8-sig") as records_file:
             self.mapper.migration_report.add_general_statistics("Number of files processed")
             start = time.time()
             records_processed = 0
-            for idx, legacy_record in enumerate(self.mapper.get_objects(records_file, file_name)):
+            for idx, legacy_record in enumerate(self.mapper.get_objects(records_file, full_path)):
                 records_processed = idx + 1
                 try:
                     self.mapper.verify_legacy_record(legacy_record, idx)
@@ -303,12 +291,14 @@ class HoldingsCsvTransformer(MigrationTaskBase):
                     logging.info(f"{idx:,} records processed. Recs/sec: {elapsed_formatted} ")
             self.total_records = records_processed
             logging.info(
-                f"Done processing {file_name} containing {self.total_records:,} records. "
+                f"Done processing {file_def.file_name} containing {self.total_records:,} records. "
                 f"Total records processed: {self.total_records:,}"
             )
 
     def post_process_holding(self, folio_rec: dict, legacy_id: str):
         HoldingsHelper.handle_notes(folio_rec)
+        HoldingsHelper.remove_empty_holdings_statements(folio_rec)
+
         if not folio_rec.get("holdingsTypeId", ""):
             folio_rec["holdingsTypeId"] = self.fallback_holdings_type["id"]
 
@@ -402,17 +392,16 @@ class HoldingsCsvTransformer(MigrationTaskBase):
 
     def merge_holding_in(
         self, incoming_holding: dict, instance_ids: list[str], legacy_item_id: str
-    ):
+    ) -> None:
         """Determines what newly generated holdingsrecords are to be merged with
         previously created ones. When that is done, it generates the correct boundwith
         parts needed.
 
         Args:
-            new_folio_holding (dict): The newly created FOLIO Holding
+            incoming_holding (dict): The newly created FOLIO Holding
             instance_ids (list): the instance IDs tied to the current item
             legacy_item_id (str): Id of the Item the holding was generated from
         """
-
         if len(instance_ids) > 1:
             # Is boundwith
             bw_key = f"bw_{incoming_holding['instanceId']}_{'_'.join(sorted(instance_ids))}"
@@ -460,20 +449,16 @@ class HoldingsCsvTransformer(MigrationTaskBase):
 
     def get_holdings_sources(self):
         res = {}
-        if self.library_configuration.folio_release != FolioRelease.juniper:
-            holdings_sources = list(
-                self.mapper.folio_client.folio_get_all(
-                    "/holdings-sources", "holdingsRecordsSources"
-                )
-            )
-            logging.info("Fetched %s holdingsRecordsSources from tenant", len(holdings_sources))
-            res = {n["name"].upper(): n["id"] for n in holdings_sources}
-            if "FOLIO" not in res:
-                raise TransformationProcessError(
-                    "", "No holdings source with name FOLIO in tenant"
-                )
-            if "MARC" not in res:
-                raise TransformationProcessError("", "No holdings source with name MARC in tenant")
+        holdings_sources = list(
+            self.mapper.folio_client.folio_get_all("/holdings-sources", "holdingsRecordsSources")
+        )
+        logging.info("Fetched %s holdingsRecordsSources from tenant", len(holdings_sources))
+        res = {n["name"].upper(): n["id"] for n in holdings_sources}
+        if "FOLIO" not in res:
+            raise TransformationProcessError("", "No holdings source with name FOLIO in tenant")
+        if "MARC" not in res:
+            raise TransformationProcessError("", "No holdings source with name MARC in tenant")
+        logging.info(json.dumps(res, indent=4))
         return res
 
 
