@@ -13,6 +13,9 @@ from urllib.error import HTTPError
 
 import requests
 from dateutil import parser as du_parser
+from folio_uuid.folio_namespaces import FOLIONamespaces
+from pydantic import BaseModel
+
 from folio_migration_tools.circulation_helper import CirculationHelper
 from folio_migration_tools.custom_dict import InsensitiveDictReader
 from folio_migration_tools.helper import Helper
@@ -25,8 +28,6 @@ from folio_migration_tools.transaction_migration.legacy_loan import LegacyLoan
 from folio_migration_tools.transaction_migration.transaction_result import (
     TransactionResult,
 )
-from folio_uuid.folio_namespaces import FOLIONamespaces
-from pydantic import BaseModel
 
 
 class LoansMigrator(MigrationTaskBase):
@@ -50,6 +51,7 @@ class LoansMigrator(MigrationTaskBase):
         library_config: LibraryConfiguration,
     ):
         csv.register_dialect("tsv", delimiter="\t")
+        self.start_datetime = datetime.now(timezone.utc)
         self.migration_report = MigrationReport()
         self.valid_legacy_loans = []
         super().__init__(library_config, task_configuration)
@@ -91,18 +93,20 @@ class LoansMigrator(MigrationTaskBase):
         self.skipped_since_already_added = 0
         self.processed_items = set()
         self.failed = {}
-        self.num_legacy_loans_processed = 0
         self.failed_and_not_dupe = {}
-        logging.info("Starting row is %s", task_configuration.starting_row)
+        logging.info("Starting row number is %s", task_configuration.starting_row)
         logging.info("Init completed")
 
     def do_work(self):
         logging.info("Starting")
+        starting_index = (
+            self.task_configuration.starting_row - 1
+            if self.task_configuration.starting_row > 0
+            else 0
+        )
         if self.task_configuration.starting_row > 1:
-            logging.info(f"Skipping {(self.task_configuration.starting_row-1)} records")
-        for num_loans, legacy_loan in enumerate(
-            self.valid_legacy_loans[self.task_configuration.starting_row :], start=1
-        ):
+            logging.info(f"Skipping {(starting_index)} records")
+        for num_loans, legacy_loan in enumerate(self.valid_legacy_loans[starting_index:], start=1):
             t0_migration = time.time()
             self.migration_report.add_general_statistics("Processed loans")
             try:
@@ -174,18 +178,13 @@ class LoansMigrator(MigrationTaskBase):
         self.migration_report.set(
             Blurbs.GeneralStatistics, "Failed loans", len(self.failed_and_not_dupe)
         )
-        self.migration_report.set(
-            Blurbs.GeneralStatistics,
-            "Total Rows in file",
-            self.num_legacy_loans_processed,
-        )
 
         self.write_failed_loans_to_file()
 
         with open(self.folder_structure.migration_reports_file, "w+") as report_file:
             report_file.write("# Loans migration results   \n")
             report_file.write(f"Time Finished: {datetime.isoformat(datetime.now(timezone.utc))}\n")
-            self.migration_report.write_migration_report(report_file)
+            self.migration_report.write_migration_report(report_file, self.start_datetime)
 
     def write_failed_loans_to_file(self):
         csv_columns = [
@@ -212,8 +211,8 @@ class LoansMigrator(MigrationTaskBase):
             user_barcodes, self.task_configuration.patron_files, self.folder_structure
         )
         for loan in self.semi_valid_legacy_loans:
-            has_item_barcode = loan.item_barcode in item_barcodes
-            has_patron_barcode = loan.patron_barcode in user_barcodes
+            has_item_barcode = loan.item_barcode in item_barcodes or not any(item_barcodes)
+            has_patron_barcode = loan.patron_barcode in user_barcodes or not any(user_barcodes)
             if has_item_barcode and has_patron_barcode:
                 self.migration_report.add_general_statistics(
                     "Loans verified against migrated user and item"
@@ -588,16 +587,6 @@ class LoansMigrator(MigrationTaskBase):
             logging.info(exception)
             return False, None, None
 
-    def make_loan_utc(self, legacy_loan: LegacyLoan):
-        if self.task_configuration.utc_difference != 0:
-            legacy_loan.due_date = legacy_loan.due_date + timedelta(
-                hours=self.task_configuration.utc_difference
-            )
-            legacy_loan.out_date = legacy_loan.out_date + timedelta(
-                hours=self.task_configuration.utc_difference
-            )
-            self.migration_report.add_general_statistics("Adjusted out and due dates to UTC")
-
 
 def timings(t0, t0func, num_objects):
     avg = num_objects / (time.time() - t0)
