@@ -1,20 +1,18 @@
 import csv
-from genericpath import isfile
+import json
 import logging
-from pathlib import Path
 import sys
 import time
 from abc import abstractmethod
-import json
+from pathlib import Path
 
-from argparse_prompt import PromptParser
 from folio_uuid.folio_namespaces import FOLIONamespaces
 from folioclient import FolioClient
+from genericpath import isfile
+
 from folio_migration_tools import library_configuration
-from folio_migration_tools.custom_exceptions import (
-    TransformationProcessError,
-    TransformationRecordFailedError,
-)
+from folio_migration_tools.custom_exceptions import TransformationProcessError
+from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
 from folio_migration_tools.folder_structure import FolderStructure
 
 
@@ -72,6 +70,36 @@ class MigrationTaskBase:
     def do_work(self):
         raise NotImplementedError
 
+    @staticmethod
+    def check_source_files(
+        source_path: Path, file_defs: list[library_configuration.FileDefinition]
+    ) -> None:
+        """Lists the source data files. Special case since we use the Items folder for holdings
+
+        Args:
+            source_path (Path): _description_
+            file_defs (list[library_configuration.FileDefinition]): _description_
+
+        Raises:
+            TransformationProcessError: _description_
+
+        """
+        files = [source_path / f.file_name for f in file_defs if isfile(source_path / f.file_name)]
+        if len(files) < len(file_defs):
+            raise TransformationProcessError(
+                "",
+                "Not all files listed in configuration found on disk",
+            )
+        if not any(files):
+            ret_str = ",".join(f.file_name for f in file_defs)
+            raise TransformationProcessError(
+                "",
+                f"Files {ret_str} not found in {source_path / 'items'}",
+            )
+        logging.info("Files to process:")
+        for filename in files:
+            logging.info("\t%s", filename)
+
     @staticmethod
     def load_id_map(map_path, raise_if_empty=False):
         if not isfile(map_path):
@@ -121,16 +149,15 @@ class MigrationTaskBase:
                 self._log(DATA_ISSUE_LVL_NUM, message, args, **kws)
 
         logging.Logger.data_issues = data_issues
-
         logger = logging.getLogger()
         logger.handlers = []
         formatter = logging.Formatter(
-            "%(asctime)s\t%(levelname)s\t%(message)s\t%(filename)s:%(lineno)d"
+            "%(asctime)s\t%(levelname)s\t%(message)s\t%(task_configuration_name)s"
         )
         stream_handler = logging.StreamHandler()
         stream_handler.addFilter(ExcludeLevelFilter(25))
         stream_handler.addFilter(ExcludeLevelFilter(26))
-
+        stream_handler.addFilter(TaskNameFilter(self.task_configuration.name))
         if debug:
             logger.setLevel(logging.DEBUG)
             stream_handler.setLevel(logging.DEBUG)
@@ -141,12 +168,15 @@ class MigrationTaskBase:
         stream_handler.setFormatter(formatter)
         logger.addHandler(stream_handler)
 
-        file_formatter = logging.Formatter("%(message)s")
+        file_formatter = logging.Formatter(
+            "%(asctime)s\t%(message)s\t%(task_configuration_name)s\t%(filename)s:%(lineno)d"
+        )
         file_handler = logging.FileHandler(
             filename=self.folder_structure.transformation_log_path, mode="w"
         )
         file_handler.addFilter(ExcludeLevelFilter(25))
         file_handler.addFilter(ExcludeLevelFilter(26))
+        file_handler.addFilter(TaskNameFilter(self.task_configuration.name))
         # file_handler.addFilter(LevelFilter(0, 20))
         file_handler.setFormatter(file_formatter)
         file_handler.setLevel(logging.INFO)
@@ -185,15 +215,6 @@ class MigrationTaskBase:
             logging.info("%s Mapped fields in mapping file map", len(list(mapped_fields)))
             return field_map
 
-    @staticmethod
-    def add_common_arguments(parser: PromptParser):
-
-        """parser.add_argument("okapi_url", help="OKAPI base url")
-        parser.add_argument("tenant_id", help="id of the FOLIO tenant.")
-        parser.add_argument("username", help="the api user")
-        parser.add_argument("base_folder", help="path base folder", type=str)
-        parser.add_argument("--password", help="the api users password", secure=True)"""
-
     def log_and_exit_if_too_many_errors(self, error: TransformationRecordFailedError, idx):
         self.num_exeptions += 1
         error.log_it()
@@ -251,7 +272,7 @@ class MigrationTaskBase:
             logging.info("No mapping setup for %s", folio_property_name)
             logging.info("%s will have default mapping if any ", folio_property_name)
             logging.info(
-                "Add a file named %s and add the field to " "the item.mapping.json file.",
+                "Add a file named %s and add the field to the item.mapping.json file.",
                 map_file_path,
             )
             return None
@@ -266,6 +287,16 @@ class ExcludeLevelFilter(logging.Filter):
         return record.levelno != self.level
 
 
+class TaskNameFilter(logging.Filter):
+    def __init__(self, task_configuration_name):
+        super().__init__()
+        self.task_configuration_name = task_configuration_name
+
+    def filter(self, record):
+        record.task_configuration_name = self.task_configuration_name
+        return True
+
+
 class LevelFilter(logging.Filter):
     def __init__(self, level):
         super().__init__()
