@@ -4,6 +4,9 @@ import sys
 from typing import Dict
 from typing import Optional
 
+from folio_uuid.folio_namespaces import FOLIONamespaces
+from pydantic import BaseModel
+
 from folio_migration_tools.custom_exceptions import TransformationProcessError
 from folio_migration_tools.custom_exceptions import TransformationRecordFailedError
 from folio_migration_tools.helper import Helper
@@ -14,8 +17,6 @@ from folio_migration_tools.mapping_file_transformation.mapping_file_mapper_base
 )
 from folio_migration_tools.mapping_file_transformation.user_mapper import UserMapper
 from folio_migration_tools.migration_tasks.migration_task_base import MigrationTaskBase
-from folio_uuid.folio_namespaces import FOLIONamespaces
-from pydantic import BaseModel
 
 
 class UserTransformer(MigrationTaskBase):
@@ -79,13 +80,21 @@ class UserTransformer(MigrationTaskBase):
                 self.folder_structure.mapping_files_folder / self.task_config.departments_map_path,
             )
             departments_mapping = []
-        self.mapper = UserMapper(
-            self.folio_client,
-            task_config,
-            library_config,
-            departments_mapping,
-            group_mapping,
+        map_path = (
+            self.folder_structure.mapping_files_folder / self.task_config.user_mapping_file_name
         )
+        with open(map_path, encoding="utf8") as mapping_file:
+            user_map = json.load(mapping_file)
+            self.mapper = UserMapper(
+                self.folio_client,
+                task_config,
+                library_config,
+                user_map,
+                departments_mapping,
+                group_mapping,
+            )
+            self.legacy_property_name = self.get_legacy_id_prop(self.user_map)
+
         logging.info("UserTransformer init done")
 
     def do_work(self):
@@ -93,22 +102,15 @@ class UserTransformer(MigrationTaskBase):
         source_path = (
             self.folder_structure.legacy_records_folder / self.task_config.user_file.file_name
         )
-        map_path = (
-            self.folder_structure.mapping_files_folder / self.task_config.user_mapping_file_name
-        )
+
         try:
             with open(
                 self.folder_structure.created_objects_path,
                 "w+",
                 encoding="utf-8",
             ) as results_file:
-                with open(source_path, encoding="utf8") as object_file, open(
-                    map_path, encoding="utf8"
-                ) as mapping_file:
+                with open(source_path, encoding="utf8") as object_file:
                     logging.info(f"processing {source_path}")
-                    user_map = json.load(mapping_file)
-                    legacy_property_name = self.get_legacy_id_prop(user_map)
-
                     file_format = "tsv" if str(source_path).endswith(".tsv") else "csv"
                     for num_users, legacy_user in enumerate(
                         self.mapper.get_users(object_file, file_format), start=1
@@ -120,8 +122,7 @@ class UserTransformer(MigrationTaskBase):
                                 print_email_warning()
                             folio_user = self.mapper.do_map(
                                 legacy_user,
-                                user_map,
-                                legacy_user.get(legacy_property_name),
+                                legacy_user.get(self.legacy_property_name),
                             )
                             self.clean_user(folio_user)
                             results_file.write(f"{json.dumps(folio_user)}\n")
@@ -138,7 +139,7 @@ class UserTransformer(MigrationTaskBase):
                             Helper.log_data_issue(tre.index_or_id, tre.message, tre.data_value)
                             logging.error(tre)
                         except TransformationProcessError as tpe:
-                            logging.error(tpe)
+                            logging.critical(tpe)
                             print(f"\n{tpe.message}: {tpe.data_value}")
                             print("\nHalting")
                             sys.exit(1)
@@ -200,7 +201,9 @@ class UserTransformer(MigrationTaskBase):
                 "Writing migration- and mapping report to %s",
                 self.folder_structure.migration_reports_file,
             )
-            self.mapper.migration_report.write_migration_report(migration_report_file)
+            self.mapper.migration_report.write_migration_report(
+                migration_report_file, self.mapper.start_datetime
+            )
             Helper.print_mapping_report(
                 migration_report_file,
                 self.total_records,
