@@ -9,6 +9,8 @@ class ReportSection(Enum):
 
 
 class Blurbs:
+    LeaderManipulation = ("Leader manipulation", "")
+    TermsMapping = ("Terms Mapping", "Reference data mapping for Terms.")
     DateTimeConversions = (
         "DateTime conversions",
         "Some date and date time strings are converted to UTC DateTime objects and then printed accoding to ISO standard.",
@@ -20,6 +22,7 @@ class Blurbs:
         "<br/>Data errors preventing records from being migrated are marked **FIX BEFORE MIGRATION**. The library is advised to clean up these errors in the source data.<br/><br/> The sections related to field counts and mapping results are marked **REVIEW**. These do not indicate errors preventing records from being migrated, but may point to data anomalies or in the mappings. The library should review these to make sure that the numbers are what one would expect, knowing the source data. Is this the expected number of serials? Is this the expected number of cartographic materials?",
     )
     DiscardedLoans = ("Discarded loans", "List of loans discarded for various resons")
+    DiscardedReserves = ("Discarded reserves", "List of reserves discarded for various resons")
     DiscardedRequests = (
         "Discarded Requests",
         "List of requests discarded for various resons",
